function [ret,x0,str]=scaoqtn3(t,x,u,flag);
%SCAOQTN3	is the M-file description of the SIMULINK system named SCAOQTN3.
%	The block-diagram can be displayed by typing: SCAOQTN3.
%
%	SYS=SCAOQTN3(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCAOQTN3 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCAOQTN3 with a FLAG of zero:
%	[SIZES]=SCAOQTN3([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[4,82,601,440])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',		'RK-23')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'30')
set_param(sys,'Min step size',	'0.02')
set_param(sys,'Max step size',	'0.02')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','solution',...
		'buffer','1500',...
		'position',[285,242,335,258])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn2'])
set_param([sys,'/','MATLAB Fcn2'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','180/pi*u(3)',...
		'Output Width','1',...
		'position',[285,193,345,227])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','v_r',...
		'buffer','1500',...
		'position',[395,202,445,218])

add_block('built-in/Scope',[sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','2000.000000',...
		'Hgain','1.000000',...
		'Vmax','4000.000000',...
		'Hmax','2.000000',...
		'Window',[29,66,351,446],...
		'position',[450,210,480,240])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','50.000000',...
		'Hgain','1.000000',...
		'Vmax','100.000000',...
		'Hmax','2.000000',...
		'Window',[318,54,640,434],...
		'position',[445,85,475,115])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','50.000000',...
		'Hgain','1.000000',...
		'Vmax','100.000000',...
		'Hmax','2.000000',...
		'Window',[29,66,351,446],...
		'position',[445,160,475,190])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',5,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','1500',...
		'position',[160,187,210,203])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',5,...
		'hide name',0,...
		'position',[105,185,125,205])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','180/pi*u(1)',...
		'Output Width','1',...
		'position',[280,98,340,132])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','v_q',...
		'buffer','1500',...
		'position',[390,152,440,168])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn1'])
set_param([sys,'/','MATLAB Fcn1'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','180/pi*(u(2)-rotation_orbitale)',...
		'Output Width','1',...
		'position',[280,143,340,177])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','v_p',...
		'buffer','1500',...
		'position',[390,107,440,123])


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[133,155,619,460])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/MATLAB Fcn'])
set_param([sys,'/','UnNamed/MATLAB Fcn'],...
		'orientation',2,...
		'MATLAB Fcn','poinsot(u)',...
		'Output Width','7',...
		'position',[95,190,145,220])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum'])
set_param([sys,'/','UnNamed/Sum'],...
		'position',[260,44,275,131])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'orientation',2,...
		'inputs','[7 3 1]',...
		'position',[180,134,210,276])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant'])
set_param([sys,'/','UnNamed/Constant'],...
		'orientation',2,...
		'Value','[Ir It Il]',...
		'position',[235,192,315,218])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant1'])
set_param([sys,'/','UnNamed/Constant1'],...
		'orientation',2,...
		'Value','rotation_orbitale',...
		'position',[235,237,315,263])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Inport',[sys,'/','UnNamed/in_1'])
set_param([sys,'/','UnNamed/in_1'],...
		'position',[25,55,45,75])

add_block('built-in/State-space',[sys,'/','UnNamed/Matrix gain.'])
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[1/Ir 0 0;0 1/It 0;0 0 1/Il;0 0 0;1 0 0;0 0 0;0 0 0 ]\/')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'position',[100,48,155,82])

add_block('built-in/Integrator',[sys,'/','UnNamed/Integrator'])
set_param([sys,'/','UnNamed/Integrator'],...
		'Initial','etat_init',...
		'position',[310,75,345,105])
add_line([sys,'/','UnNamed'],[160,65;250,65])
add_line([sys,'/','UnNamed'],[90,205;70,205;70,110;250,110])
add_line([sys,'/','UnNamed'],[175,205;155,205])
add_line([sys,'/','UnNamed'],[230,250;220,250])
add_line([sys,'/','UnNamed'],[230,205;220,205])
add_line([sys,'/','UnNamed'],[350,90;405,90])
add_line([sys,'/','UnNamed'],[360,90;360,160;220,160])
add_line([sys,'/','UnNamed'],[280,90;300,90])
add_line([sys,'/','UnNamed'],[50,65;90,65])
set_param([sys,'/','UnNamed'],...
		'Mask Display','DYNAMIQUE\n\nSATELLITE\n\nQUATERNIONS')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[115,79,245,151])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Value','[60 40 0]''',...
		'position',[15,101,75,129])

add_block('built-in/Note',[sys,'/','Sign:GUIZIOU'])
set_param([sys,'/','Sign:GUIZIOU'],...
		'position',[50,270,51,271])

add_block('built-in/Note',[sys,'/',['QUATERNIONS ===>ETUDE DU MOUVEMENT',13,' SATELLITE SPINNE SOUS COUPLE CONSTANT']])
set_param([sys,'/',['QUATERNIONS ===>ETUDE DU MOUVEMENT',13,' SATELLITE SPINNE SOUS COUPLE CONSTANT']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[275,5,276,6])

add_block('built-in/Note',[sys,'/','Gradient de gravit absent'])
set_param([sys,'/','Gradient de gravit absent'],...
		'ForeGround',5,...
		'position',[265,50,266,51])

add_block('built-in/Note',[sys,'/','Vrification de la constance du moment cintique'])
set_param([sys,'/','Vrification de la constance du moment cintique'],...
		'ForeGround',5,...
		'position',[415,270,416,271])

add_block('built-in/Note',[sys,'/',' janvier 1995'])
set_param([sys,'/',' janvier 1995'],...
		'position',[440,355,441,356])

add_block('built-in/Note',[sys,'/','sign: GUIZIOU'])
set_param([sys,'/','sign: GUIZIOU'],...
		'position',[370,355,371,356])

add_block('built-in/Scope',[sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'ForeGround',4,...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','1000.000000',...
		'Hgain','10.000000',...
		'Vmax','2000.000000',...
		'Hmax','20.000000',...
		'Window',[0,60,322,440])
set_param([sys,'/','Scope3'],...
		'position',[445,290,475,320])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','quatpass(u(4:7))*[u(8)*u(1) u(9)*u(2) u(10)*u(3)]''',...
		'Output Width','3',...
		'position',[340,288,400,322])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[7 3]',...
		'position',[280,277,305,333])

add_block('built-in/Constant',[sys,'/','Constant1'])
set_param([sys,'/','Constant1'],...
		'hide name',0,...
		'Value','[Ir It Il]',...
		'position',[150,307,230,333])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','moment_cin_abs',...
		'buffer','1500',...
		'position',[455,336,555,354])


%     Subsystem  'XY Graph'.

new_system([sys,'/','XY Graph'])
set_param([sys,'/','XY Graph'],'Location',[0,0,274,193])

add_block('built-in/Inport',[sys,'/','XY Graph/y'])
set_param([sys,'/','XY Graph/y'],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/','XY Graph/x'])
set_param([sys,'/','XY Graph/x'],...
		'position',[10,30,30,50])

add_block('built-in/Mux',[sys,'/','XY Graph/Mux'])
set_param([sys,'/','XY Graph/Mux'],...
		'inputs','2',...
		'position',[100,61,130,94])

add_block('built-in/S-function',[sys,'/',['XY Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['XY Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunxy',...
		'parameters','ax',...
		'position',[185,70,235,90])
add_line([sys,'/','XY Graph'],[35,110;70,110;70,85;90,85])
add_line([sys,'/','XY Graph'],[35,40;70,40;70,70;90,70])
add_line([sys,'/','XY Graph'],[135,80;175,80])
set_param([sys,'/','XY Graph'],...
		'Mask Display','plot(0,0,100,100,[12,91,91,12,12],[90,90,45,45,90],[51,57,65,75,80,79,75,67,60,54,51,48,42,34,28,27,31,42,51],[71,68,66,66,72,79,83,84,81,77,71,60,54,54,58,65,71,74,71])')
set_param([sys,'/','XY Graph'],...
		'Mask Type','XY scope.',...
		'Mask Dialogue','XY scope using MATLAB graph window.\nFirst input is used as time base.\nEnter plotting ranges.|x-min|x-max|y-min|y-max')
set_param([sys,'/','XY Graph'],...
		'Mask Translate','ax = [@1, @2, @3, @4];',...
		'Mask Help','This block can be used to explore limit cycles. Look at the m-file sfunxy.m to see how it works.',...
		'Mask Entries','-100\/100\/-100\/100\/')


%     Finished composite block 'XY Graph'.

set_param([sys,'/','XY Graph'],...
		'Drop Shadow',4,...
		'position',[510,112,550,163])
add_line(sys,[80,115;105,115])
add_line(sys,[130,195;150,195])
add_line(sys,[250,115;270,115])
add_line(sys,[345,115;380,115])
add_line(sys,[345,115;345,100;435,100])
add_line(sys,[260,115;260,250;275,250])
add_line(sys,[260,160;270,160])
add_line(sys,[345,160;380,160])
add_line(sys,[360,160;360,175;435,175])
add_line(sys,[350,210;385,210])
add_line(sys,[365,210;365,225;440,225])
add_line(sys,[260,210;275,210])
add_line(sys,[405,305;435,305])
add_line(sys,[310,305;330,305])
add_line(sys,[235,320;270,320])
add_line(sys,[260,250;260,290;270,290])
add_line(sys,[415,305;415,345;445,345])
add_line(sys,[370,115;370,125;500,125])
add_line(sys,[370,160;500,150])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
