function [ret,x0,str]=scaoqtn4(t,x,u,flag);
%SCAOQTN4	is the M-file description of the SIMULINK system named SCAOQTN4.
%	The block-diagram can be displayed by typing: SCAOQTN4.
%
%	SYS=SCAOQTN4(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCAOQTN4 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCAOQTN4 with a FLAG of zero:
%	[SIZES]=SCAOQTN4([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[18,66,607,386])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',		'RK-45')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'5000')
set_param(sys,'Min step size',	'20')
set_param(sys,'Max step size',	'20')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')

add_block('built-in/Note',[sys,'/','Gradient de gravit'])
set_param([sys,'/','Gradient de gravit'],...
		'ForeGround',5,...
		'position',[275,55,276,56])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','20.000000',...
		'Hgain','10000.000000',...
		'Vmax','40.000000',...
		'Hmax','20000.000000',...
		'Window',[383,62,746,426])
open_system([sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'position',[465,130,495,160])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','1500',...
		'position',[395,197,445,213])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn2'])
set_param([sys,'/','MATLAB Fcn2'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','roulis(u)',...
		'Output Width','1',...
		'position',[300,188,360,222])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','1500',...
		'position',[395,157,445,173])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','1500',...
		'position',[395,112,445,128])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','-180/pi*asin(2*(u(5)*u(7)-u(4)*u(6)))',...
		'Output Width','1',...
		'position',[300,103,360,137])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn1'])
set_param([sys,'/','MATLAB Fcn1'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','lacet(u)',...
		'Output Width','1',...
		'position',[300,148,360,182])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',5,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','2500',...
		'position',[180,192,230,208])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',5,...
		'hide name',0,...
		'position',[125,190,145,210])


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[133,155,619,460])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum'])
set_param([sys,'/','UnNamed/Sum'],...
		'position',[260,44,275,131])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'orientation',2,...
		'inputs','[7 3 1]',...
		'position',[180,134,210,276])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant'])
set_param([sys,'/','UnNamed/Constant'],...
		'orientation',2,...
		'Value','[Ir It Il]',...
		'position',[235,192,315,218])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant1'])
set_param([sys,'/','UnNamed/Constant1'],...
		'orientation',2,...
		'Value','rotation_orbitale',...
		'position',[235,237,315,263])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Inport',[sys,'/','UnNamed/in_1'])
set_param([sys,'/','UnNamed/in_1'],...
		'position',[25,55,45,75])

add_block('built-in/State-space',[sys,'/','UnNamed/Matrix gain.'])
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[1/Ir 0 0;0 1/It 0;0 0 1/Il;0 0 0;1 0 0;0 0 0;0 0 0 ]\/')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'position',[100,48,155,82])

add_block('built-in/Integrator',[sys,'/','UnNamed/Integrator'])
set_param([sys,'/','UnNamed/Integrator'],...
		'Initial','etat_init',...
		'position',[310,75,345,105])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/MATLAB Fcn'])
set_param([sys,'/','UnNamed/MATLAB Fcn'],...
		'orientation',2,...
		'MATLAB Fcn','der_sys(u)',...
		'Output Width','7',...
		'position',[90,190,140,220])
add_line([sys,'/','UnNamed'],[160,65;250,65])
add_line([sys,'/','UnNamed'],[85,205;70,205;70,110;250,110])
add_line([sys,'/','UnNamed'],[175,205;150,205])
add_line([sys,'/','UnNamed'],[230,250;220,250])
add_line([sys,'/','UnNamed'],[230,205;220,205])
add_line([sys,'/','UnNamed'],[350,90;405,90])
add_line([sys,'/','UnNamed'],[360,90;360,160;220,160])
add_line([sys,'/','UnNamed'],[280,90;300,90])
add_line([sys,'/','UnNamed'],[50,65;90,65])
set_param([sys,'/','UnNamed'],...
		'Mask Display','DYNAMIQUE\n\nSATELLITE\n\nQUATERNIONS',...
		'Mask Type','',...
		'Mask Dialogue','SATELLITE 3 ANGLES|Ir roulis (kg-m)|It tangage (kg-m)|Il lacet (kg-m)')
set_param([sys,'/','UnNamed'],...
		'Mask Translate','global Ir It Il etat_init rotation_orbitale;Ir=@1;It=@2;Il=@3',...
		'Mask Help','',...
		'Mask Entries','135\/135\/7\/')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[135,84,265,156])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Value','[0 0 0]''',...
		'position',[35,106,95,134])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','200.000000',...
		'Hgain','10000.000000',...
		'Vmax','400.000000',...
		'Hmax','20000.000000',...
		'Window',[0,55,380,409])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[465,85,495,115])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','solution',...
		'buffer','2500',...
		'position',[310,237,360,253])

add_block('built-in/Note',[sys,'/','Sign:GUIZIOU janvier 1995'])
set_param([sys,'/','Sign:GUIZIOU janvier 1995'],...
		'position',[295,295,296,296])


%     Subsystem  'Extras2'.

new_system([sys,'/','Extras2'])
set_param([sys,'/','Extras2'],'Location',[4,118,108,334])
set_param([sys,'/','Extras2'],...
		'Mask Display','VISUALISATION\npar double clic souris',...
		'Mask Type','',...
		'Mask Dialogue','eval(''visuqtn4'')',...
		'Mask Translate','',...
		'Mask Help','')


%     Finished composite block 'Extras2'.

set_param([sys,'/','Extras2'],...
		'ForeGround',2,...
		'BackGround',5,...
		'hide name',0,...
		'position',[80,265,220,310])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,118,108,334])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\nSIMULATION SCAOQTN4\npar double clic souris',...
		'Mask Type','',...
		'Mask Dialogue','eval(''scaodat4'')',...
		'Mask Translate','',...
		'Mask Help','')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',2,...
		'BackGround',5,...
		'hide name',0,...
		'position',[380,270,520,315])

add_block('built-in/Note',[sys,'/',['QUATERNIONS:ETUDE DU TANGAGE,ROULIS',13,'ET LACET (Petits angles)']])
set_param([sys,'/',['QUATERNIONS:ETUDE DU TANGAGE,ROULIS',13,'ET LACET (Petits angles)']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[302,10,303,11])

add_block('built-in/Scope',[sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','20.000000',...
		'Hgain','10000.000000',...
		'Vmax','40.000000',...
		'Hmax','20000.000000',...
		'Window',[310,89,640,412])
open_system([sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'position',[465,165,495,195])
add_line(sys,[100,120;125,120])
add_line(sys,[150,200;170,200])
add_line(sys,[270,120;290,120])
add_line(sys,[365,120;385,120])
add_line(sys,[280,120;280,245;300,245])
add_line(sys,[280,165;290,165])
add_line(sys,[365,165;385,165])
add_line(sys,[375,165;375,145;455,145])
add_line(sys,[365,205;385,205])
add_line(sys,[375,205;375,180;455,180])
add_line(sys,[280,205;290,205])
add_line(sys,[375,120;375,100;455,100])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
