function [ret,x0,str]=scaoqtn5(t,x,u,flag);
%SCAOQTN5	is the M-file description of the SIMULINK system named SCAOQTN5.
%	The block-diagram can be displayed by typing: SCAOQTN5.
%
%	SYS=SCAOQTN5(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCAOQTN5 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCAOQTN5 with a FLAG of zero:
%	[SIZES]=SCAOQTN5([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[30,97,584,446])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',		'RK-45')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'30')
set_param(sys,'Min step size',	'0.02')
set_param(sys,'Max step size',	'0.02')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[133,155,619,460])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/MATLAB Fcn'])
set_param([sys,'/','UnNamed/MATLAB Fcn'],...
		'orientation',2,...
		'MATLAB Fcn','lagrange(u)',...
		'Output Width','7',...
		'position',[95,190,145,220])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum'])
set_param([sys,'/','UnNamed/Sum'],...
		'position',[260,44,275,131])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'orientation',2,...
		'inputs','[7 2]',...
		'position',[180,134,210,276])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Inport',[sys,'/','UnNamed/in_1'])
set_param([sys,'/','UnNamed/in_1'],...
		'position',[25,55,45,75])

add_block('built-in/State-space',[sys,'/','UnNamed/Matrix gain.'])
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[1/A 0 0;0 1/A 0;0 0 1/C;0 0 0;1 0 0;0 0 0;0 0 0 ]\/')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'position',[100,48,155,82])

add_block('built-in/Integrator',[sys,'/','UnNamed/Integrator'])
set_param([sys,'/','UnNamed/Integrator'],...
		'Initial','etat_init',...
		'position',[310,75,345,105])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant'])
set_param([sys,'/','UnNamed/Constant'],...
		'orientation',2,...
		'Value','[A C]',...
		'position',[240,227,320,253])
add_line([sys,'/','UnNamed'],[160,65;250,65])
add_line([sys,'/','UnNamed'],[90,205;70,205;70,110;250,110])
add_line([sys,'/','UnNamed'],[175,205;155,205])
add_line([sys,'/','UnNamed'],[235,240;220,240])
add_line([sys,'/','UnNamed'],[350,90;405,90])
add_line([sys,'/','UnNamed'],[360,90;360,170;220,170])
add_line([sys,'/','UnNamed'],[280,90;300,90])
add_line([sys,'/','UnNamed'],[50,65;90,65])
set_param([sys,'/','UnNamed'],...
		'Mask Display','DYNAMIQUE\n\nSATELLITE\n\nQUATERNIONS')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[150,109,280,181])

add_block('built-in/Note',[sys,'/','Sign: GUIZIOU 1995'])
set_param([sys,'/','Sign: GUIZIOU 1995'],...
		'position',[490,330,491,331])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Gain','Mgd',...
		'position',[70,127,105,163])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn2'])
set_param([sys,'/','MATLAB Fcn2'],...
		'orientation',2,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','cpl_pes(u)',...
		'Output Width','3',...
		'position',[160,202,265,238])

add_block('built-in/Note',[sys,'/',['QUATERNIONS:',13,'ETUDE DU MOUVEMENT DE LAGRANGE ET POISSON']])
set_param([sys,'/',['QUATERNIONS:',13,'ETUDE DU MOUVEMENT DE LAGRANGE ET POISSON']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[285,5,286,6])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','out_x_y(u)',...
		'Output Width','2',...
		'position',[355,126,435,164])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','x_y',...
		'position',[470,137,520,153])

add_block('built-in/Note',[sys,'/',['SORTIE DE LA TRAJECTOIRE',13,'DE L''EXTREMITE DE L''AXE  ',13,'z SUR LE PLAN XOY']])
set_param([sys,'/',['SORTIE DE LA TRAJECTOIRE',13,'DE L''EXTREMITE DE L''AXE  ',13,'z SUR LE PLAN XOY']],...
		'ForeGround',3,...
		'Font Size',12,...
		'position',[440,185,441,186])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',5,...
		'position',[45,248,85,292])
add_line(sys,[285,145;345,145])
add_line(sys,[110,145;140,145])
add_line(sys,[155,220;20,220;20,145;60,145])
add_line(sys,[325,145;325,220;275,220])
add_line(sys,[440,145;460,145])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
