function [ret,x0,str]=scaoqtn2(t,x,u,flag);
%SCAOQTN2	is the M-file description of the SIMULINK system named SCAOQTN2.
%	The block-diagram can be displayed by typing: SCAOQTN2.
%
%	SYS=SCAOQTN2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCAOQTN2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCAOQTN2 with a FLAG of zero:
%	[SIZES]=SCAOQTN2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[30,97,598,446])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',		'RK-45')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'10')
set_param(sys,'Min step size',	'0.1')
set_param(sys,'Max step size',	'0.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[119,104,605,409])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum'])
set_param([sys,'/','UnNamed/Sum'],...
		'position',[260,44,275,131])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Inport',[sys,'/','UnNamed/in_1'])
set_param([sys,'/','UnNamed/in_1'],...
		'position',[25,55,45,75])

add_block('built-in/State-space',[sys,'/','UnNamed/Matrix gain.'])
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[1/Ir 0 0;0 1/It 0;0 0 1/Il;0 0 0;1 0 0;0 0 0;0 0 0 ]\/')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'position',[100,48,155,82])

add_block('built-in/Integrator',[sys,'/','UnNamed/Integrator'])
set_param([sys,'/','UnNamed/Integrator'],...
		'Initial','etat_init',...
		'position',[310,75,345,105])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'orientation',2,...
		'inputs','[7 3]',...
		'position',[180,119,215,206])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/MATLAB Fcn'])
set_param([sys,'/','UnNamed/MATLAB Fcn'],...
		'orientation',2,...
		'MATLAB Fcn','poinsot(u)',...
		'Output Width','7',...
		'position',[95,150,145,180])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant'])
set_param([sys,'/','UnNamed/Constant'],...
		'orientation',2,...
		'Value','[Ir It Il]',...
		'position',[240,172,320,198])
add_line([sys,'/','UnNamed'],[160,65;250,65])
add_line([sys,'/','UnNamed'],[90,165;70,165;70,110;250,110])
add_line([sys,'/','UnNamed'],[175,165;155,165])
add_line([sys,'/','UnNamed'],[235,185;225,185])
add_line([sys,'/','UnNamed'],[350,90;405,90])
add_line([sys,'/','UnNamed'],[360,90;360,140;225,140])
add_line([sys,'/','UnNamed'],[280,90;300,90])
add_line([sys,'/','UnNamed'],[50,65;90,65])
set_param([sys,'/','UnNamed'],...
		'Mask Display','DYNAMIQUE\n\nSATELLITE\n\nQUATERNIONS',...
		'Mask Type','',...
		'Mask Dialogue','DYNAMIQUE DE POINSOT|Ir (Inertie roulis en kg-m)|It (Inertie tangage en kg-m)|Il (Inertie lacet en kg-m)')
set_param([sys,'/','UnNamed'],...
		'Mask Translate','global Ir It Il etat_init;Ir=@1;It=@2;Il=@3',...
		'Mask Help','',...
		'Mask Entries','135\/135\/8\/')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[115,109,245,181])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','v_p',...
		'buffer','1500',...
		'position',[390,137,440,153])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn1'])
set_param([sys,'/','MATLAB Fcn1'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','180/pi*u(2)',...
		'Output Width','1',...
		'position',[280,173,340,207])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','v_q',...
		'buffer','1500',...
		'position',[390,182,440,198])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','180/pi*u(1)',...
		'Output Width','1',...
		'position',[280,128,340,162])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',5,...
		'hide name',0,...
		'position',[105,215,125,235])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',5,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','1500',...
		'position',[160,217,210,233])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Value','[0 0 0]''',...
		'position',[20,131,80,159])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','solution',...
		'buffer','1500',...
		'position',[285,217,335,233])

add_block('built-in/Note',[sys,'/',['QUATERNIONS:',13,'ETUDE DU MOUVEMENT DE POINSOT']])
set_param([sys,'/',['QUATERNIONS:',13,'ETUDE DU MOUVEMENT DE POINSOT']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[280,5,281,6])

add_block('built-in/Note',[sys,'/','p q r qo q1 q2 q3 q4)'])
set_param([sys,'/','p q r qo q1 q2 q3 q4)'],...
		'ForeGround',3,...
		'position',[385,215,386,216])

add_block('built-in/Note',[sys,'/','sign: GUIZIOU'])
set_param([sys,'/','sign: GUIZIOU'],...
		'position',[375,325,376,326])

add_block('built-in/Note',[sys,'/',' janvier 1995'])
set_param([sys,'/',' janvier 1995'],...
		'position',[445,325,446,326])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','100.000000',...
		'Hgain','10.000000',...
		'Vmax','200.000000',...
		'Hmax','20.000000',...
		'Window',[318,54,640,434],...
		'position',[400,105,430,135])


%     Subsystem  'XY Graph'.

new_system([sys,'/','XY Graph'])
set_param([sys,'/','XY Graph'],'Location',[0,0,274,193])

add_block('built-in/Inport',[sys,'/','XY Graph/y'])
set_param([sys,'/','XY Graph/y'],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/','XY Graph/x'])
set_param([sys,'/','XY Graph/x'],...
		'position',[10,30,30,50])

add_block('built-in/Mux',[sys,'/','XY Graph/Mux'])
set_param([sys,'/','XY Graph/Mux'],...
		'inputs','2',...
		'position',[100,61,130,94])

add_block('built-in/S-function',[sys,'/',['XY Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['XY Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunxy',...
		'parameters','ax',...
		'position',[185,70,235,90])
add_line([sys,'/','XY Graph'],[35,110;70,110;70,85;90,85])
add_line([sys,'/','XY Graph'],[35,40;70,40;70,70;90,70])
add_line([sys,'/','XY Graph'],[135,80;175,80])
set_param([sys,'/','XY Graph'],...
		'Mask Display','plot(0,0,100,100,[12,91,91,12,12],[90,90,45,45,90],[51,57,65,75,80,79,75,67,60,54,51,48,42,34,28,27,31,42,51],[71,68,66,66,72,79,83,84,81,77,71,60,54,54,58,65,71,74,71])')
set_param([sys,'/','XY Graph'],...
		'Mask Type','XY scope.',...
		'Mask Dialogue','XY scope using MATLAB graph window.\nFirst input is used as time base.\nEnter plotting ranges.|x-min|x-max|y-min|y-max')
set_param([sys,'/','XY Graph'],...
		'Mask Translate','ax = [@1, @2, @3, @4];',...
		'Mask Help','This block can be used to explore limit cycles. Look at the m-file sfunxy.m to see how it works.',...
		'Mask Entries','-wmax\/wmax\/-wmax\/wmax\/')


%     Finished composite block 'XY Graph'.

set_param([sys,'/','XY Graph'],...
		'Drop Shadow',4,...
		'position',[450,146,490,184])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','100.000000',...
		'Hgain','10.000000',...
		'Vmax','200.000000',...
		'Hmax','20.000000',...
		'Window',[0,60,322,440])
open_system([sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'position',[440,200,470,230])

add_block('built-in/Note',[sys,'/','Gradient de gravit absent'])
set_param([sys,'/','Gradient de gravit absent'],...
		'ForeGround',5,...
		'position',[405,55,406,56])


%     Subsystem  'Extras'.

new_system([sys,'/','Extras'])
set_param([sys,'/','Extras'],'Location',[4,118,108,334])
set_param([sys,'/','Extras'],...
		'Mask Display','INITIALISATION\nSIMULATION SCAOQTN2\npar double clic souris',...
		'Mask Type','',...
		'Mask Dialogue','eval(''scaodat2'')',...
		'Mask Translate','',...
		'Mask Help','')


%     Finished composite block 'Extras'.

set_param([sys,'/','Extras'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[335,275,475,320])

add_block('built-in/Note',[sys,'/',['Couple ',13,'d''entre',13,'nul']])
set_param([sys,'/',['Couple ',13,'d''entre',13,'nul']],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',14,...
		'position',[50,165,51,166])
add_line(sys,[85,145;105,145])
add_line(sys,[130,225;150,225])
add_line(sys,[250,145;270,145])
add_line(sys,[345,145;380,145])
add_line(sys,[345,145;345,120;390,120])
add_line(sys,[260,145;260,225;275,225])
add_line(sys,[260,190;270,190])
add_line(sys,[345,190;380,190])
add_line(sys,[345,190;345,215;430,215])
add_line(sys,[365,145;365,155;440,155])
add_line(sys,[365,190;365,175;440,175])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
